pub enum TagFormat {
    F1,
    F2,
    F4,
    F8,
    Size,
    VSize,
    FSize,
    Class,
    OptimizedVSize,
}
This tag format describes how the data is encoded and how it can be skipped by the decoding code if the tagged parameter is present in the buffer but is not known to the receiver.

Variants



F1

A fixed size numeric encoded on 1 byte such as bool or int8.



F2

A fixed size numeric encoded on 2 bytes such as int16.



F4

A fixed size numeric encoded on 4 bytes such as int32 or float32.



F8

A fixed size numeric encoded on 8 bytes such as int64 or float64.



Size

A variable-length size encoded on 1 or 5 bytes.



VSize

A variable-length size followed by size bytes.



FSize

A fixed length size (encoded on 4 bytes) followed by size bytes.



Class

Represents a class, but is no longer encoded or decoded.



OptimizedVSize

Pseudo non-encoded format: like VSize but the size is optimized out.