pub struct Dictionary {
pub key_type: TypeRef,
pub value_type: TypeRef,
}Fields
key_type: TypeRefvalue_type: TypeRefTrait Implementations
Sourceimpl AsTypes for Dictionary
impl AsTypes for Dictionary
fn concrete_type(&self) -> Types<'_>
Sourceimpl Debug for Dictionary
impl Debug for Dictionary
Sourceimpl<'a> TryFrom<&'a Node> for &'a Dictionary
impl<'a> TryFrom<&'a Node> for &'a Dictionary
Sourcefn try_from(node: &'a Node) -> Result<&'a Dictionary, Self::Error>
fn try_from(node: &'a Node) -> Result<&'a Dictionary, Self::Error>
Attempts to unwrap a node to the specified concrete type.
If the Slice element held by the node is the specified type, this succeeds, and returns the unwrapped element in the requested container. Otherwise this method fails and returns an error message.
Sourcetype Error = LookupError
type Error = LookupError
The type returned in the event of a conversion error.
Sourceimpl Type for Dictionary
impl Type for Dictionary
fn type_string(&self) -> String