Location

Struct Location 

pub struct Location {
    pub row: usize,
    pub col: usize,
}
Stores the row and column numbers of a location in a Slice file. These values are indexed starting at 1 instead of 0 for human readability. Ex: (1,1) is the start of a file: the first column in the first row.

Fields

row: usizecol: usize

Implementations

Source

impl Location

pub fn is_within(&self, span: &Span) -> bool

Returns true if this Location is within the specified Span (including the span’s boundary).