Module slice_options

Module slice_options 

Structs

Plugin
SliceOptions
This struct is responsible for parsing the command line options of the ‘slicec’ compiler. The option parsing capabilities are generated on the struct by the clap::Parser derive macro.

Enums

DiagnosticFormat
This enum is used to specify the format for emitted diagnostics.