pub struct SliceFile {
pub filename: String,
pub relative_path: String,
pub raw_text: String,
pub module: Option<WeakPtr<Module>>,
pub attributes: Vec<WeakPtr<Attribute>>,
pub contents: Vec<Definition>,
pub is_source: bool,
}Fields
filename: Stringrelative_path: Stringraw_text: Stringmodule: Option<WeakPtr<Module>>attributes: Vec<WeakPtr<Attribute>>contents: Vec<Definition>is_source: boolImplementations
Sourceimpl SliceFile
impl SliceFile
Sourcepub fn visit_with(&self, visitor: &mut impl Visitor)
pub fn visit_with(&self, visitor: &mut impl Visitor)
Visits the SliceFile with the provided visitor.
This function first calls visitor.visit_file, then if the file contains a module declaration it calls
visitor.visit_module, and finally it recursively visits any definitions defined in the file.