Structs
- Plugin
- Slice
Options - This struct is responsible for parsing the command line options of the ‘slicec’ compiler.
The option parsing capabilities are generated on the struct by the
clap::Parserderive macro.
Enums
- Diagnostic
Format - This enum is used to specify the format for emitted diagnostics.