Module slice_options

Module slice_options 

Structs

SliceOptions
This struct is responsible for parsing the command line options common to all slice compilers. The option parsing capabilities are generated on the struct by the clap macro.

Enums

DiagnosticFormat
This enum is used to specify the format for emitted diagnostics.