Module slicec::slice_options
source · Structs
- This struct is responsible for parsing the command line options common to all slice compilers. The option parsing capabilities are generated on the struct by the
clapmacro.
Enums
- This enum is used to specify the format for emitted diagnostics.