Struct slicec::slice_options::SliceOptions
source · pub struct SliceOptions {
pub sources: Vec<String>,
pub references: Vec<String>,
pub defined_symbols: Vec<String>,
pub allowed_lints: Vec<String>,
pub dry_run: bool,
pub output_dir: Option<String>,
pub diagnostic_format: DiagnosticFormat,
pub disable_color: bool,
}Expand description
This struct is responsible for parsing the command line options common to all slice compilers.
The option parsing capabilities are generated on the struct by the clap macro.
Fields
sources: Vec<String>List of Slice files to compile.
references: Vec<String>Add a directory or Slice file to the list of references.
defined_symbols: Vec<String>Define a preprocessor symbol.
allowed_lints: Vec<String>Instruct the compiler to allow the specified lint.
dry_run: boolValidate input files without generating code for them.
output_dir: Option<String>Set the output directory for the generated code. Defaults to the current working directory.
diagnostic_format: DiagnosticFormatSet which format to emit errors and warnings with.
disable_color: boolDisable ANSI color codes in diagnostic output.