pub struct OwnedPtr<T: ?Sized> { /* private fields */ }Expand description
Represents a pointer that owns the data it’s pointing to. When this pointer is dropped, it ensures the pointed to data is dropped as well.
This can be used in conjunction with WeakPtr to form complex (and sometimes cyclic) data structures while still
adhering to Rust’s ownership rules, and avoiding un-droppable memory cycles.
Implementations
Sourceimpl<T: ?Sized> OwnedPtr<T>
impl<T: ?Sized> OwnedPtr<T>
pub fn borrow(&self) -> &T
Sourcepub unsafe fn borrow_mut(&mut self) -> &mut T
pub unsafe fn borrow_mut(&mut self) -> &mut T
Safety
This function doesn’t use unsafe Rust, but is marked unsafe because the invoker must GUARANTEE there are no other references to the underlying data when calling this function.
The borrow checker can ensure that there are no other references through this OwnedPtr,
but it’s possible to obtain a reference via WeakPtr::borrow instead. Because WeakPtr
uses raw pointers, the borrow checker can’t reason about these accesses. So we have to
enforce Rust’s borrow policy manually by ensuring this mutable borrow is the ONLY borrow.
Mutating the underlying data while another reference to it still exists, is undefined behavior. So ONLY call this function if you are CERTAIN that NO other references exist.
pub fn downgrade(&self) -> WeakPtr<T>
pub fn downcast<U: 'static>(self) -> Result<OwnedPtr<U>, OwnedPtr<T>>
pub fn from_inner(inner: (Box<T>, TypeId)) -> Self
pub fn into_inner(self) -> (Box<T>, TypeId)